@@ -97,6 +97,7 @@ See also the `profile' slot in the `browser' class.")
               !important
               :min-height "2rem")
             `((:and .button :hover)
+              :cursor "pointer"
               :opacity 0.8)
             `((:and .button (:or :visited :active))
               :color ,theme:background)
@@ -696,6 +697,11 @@ store them somewhere and `ffi-buffer-delete' them once done."))
               :font-weight 500)
             `(a
               :color ,theme:primary)
+            `((:and a :hover)
+              :cursor "pointer"
+              :text-decoration "underline")
+            `((:and a :active)
+              :opacity 0.6)
             `("#close"
               :position "fixed"
               :top "4px"
@@ -721,6 +727,7 @@ store them somewhere and `ffi-buffer-delete' them once done."))
               :background-color ,theme:accent
               :color ,theme:on-accent)
             `((:and .button :hover)
+              :cursor "pointer"
               :opacity 0.8)
             `((:and .button (:or :visited :active))
               :color ,theme:background)
@@ -860,6 +867,7 @@ store them somewhere and `ffi-buffer-delete' them once done."))
               :background-color ,theme:accent
               :color ,theme:on-accent)
             `((:and .button :hover)
+              :cursor "pointer"
               :opacity 0.6)
             `((:and .button (:or :visited :active))
               :color ,theme:background)
